==> attal_0.8.orig.tar.gz: attal-0.8/i18n/ru/attal_ai_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: ИИ-клиент</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Уровень подробности комментариев: многословный</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Многословный</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Нормальный</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критический</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Отсутствуют</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Установить соединение</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Разорвать соединение</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Уровень подробности комментариев</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Соединение невозможно</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Вы уже соединены с сервером. Пожалуйста, разорвите соединение сначала.</translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Уровень подробности комментариев: Нормальный</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Уровень подробности комментариев: Критический</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation>Уровень подробности комментариев: Отсутствуют</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished">Установить соединение</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/i18n/ru/attal_ai_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: ИИ-клиент</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Уровень подробности комментариев: многословный</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Многословный</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Нормальный</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критический</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Отсутствуют</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Установить соединение</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Разорвать соединение</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Уровень подробности комментариев</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Соединение невозможно</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Вы уже соединены с сервером. Пожалуйста, разорвите соединение сначала.</translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Уровень подробности комментариев: Нормальный</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Уровень подробности комментариев: Критический</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation>Уровень подробности комментариев: Отсутствуют</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Подключиться к серверу</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Подключиться к серверу</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>П&amp;рервать соединение</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Невозможно загрузить тему</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Тема</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>не была успешно загружена</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Соединение с сервером</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Название:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Установить соединение</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
</TS>
